@@ -42,7 +42,7 @@ gp_globals$base_url = "http://biit.cs.ut.ee/gprofiler"
 #' @param user_threshold custom p-value threshold, results with a larger p-value are
 #'  excluded.
 #' @param correction_method the algorithm used for multiple testing correction, one of "gSCS" (synonyms: "analytical", "g_SCS"), "fdr" (synonyms: "false_discovery_rate"), "bonferroni".
-#' @param domain_scope how to define statistical domain, one of "annotated", "known".
+#' @param domain_scope how to define statistical domain, one of "annotated", "known" or "custom".
 #' @param custom_bg vector of gene names to use as a statistical background. If given, the domain_scope is set to 'custom'.
 #' @param numeric_ns namespace to use for fully numeric IDs.
 #' @param sources a vector of data sources to use. Currently, these include
@@ -70,7 +70,7 @@ gost <- function(query,
                       evcodes = FALSE,
                       user_threshold = 0.05,
                       correction_method = c("g_SCS", "bonferroni", "fdr", "false_discovery_rate", "gSCS", "analytical"),
-                      domain_scope = c("annotated", "known"),
+                      domain_scope = c("annotated", "known", "custom"),
                       custom_bg = NULL,
                       numeric_ns  = "",
                       sources = NULL
